@@ -14,7 +14,7 @@
 #' the data frame
 #'
 #' @usage
-#' teamBatsmenPartnershipMatch(match,theTeam,opposition, plot=TRUE)
+#' teamBatsmenPartnershipMatch(match,theTeam,opposition, plot=1)
 #'
 #' @param match
 #' The match between the teams
@@ -26,7 +26,7 @@
 #' The opposition team
 #'
 #' @param plot
-#' If plot=TRUE then a plot is created otherwise a data frame is returned
+#'  Plot=1 (static),plot=2(interactive),plot=3(table)
 #'
 #' @return df
 #' The data frame of the batsmen partnetships
@@ -58,21 +58,34 @@
 #'
 #' @export
 #'
-teamBatsmenPartnershipMatch <- function(match,theTeam,opposition,plot=TRUE){
+teamBatsmenPartnershipMatch <- function(match,theTeam,opposition,plot=1){
     team=batsman=nonStriker=runs=runsScored=NULL
+    ggplotly=NULL
     a <-filter(match,team==theTeam)
     # Group batsman with non strikers and compute partnerships
     df <- data.frame(summarise(group_by(a,batsman,nonStriker),sum(runs)))
     names(df) <- c("batsman","nonStriker","runs")
+    print(dim(df))
 
-    if(plot==TRUE){
+    if(plot==1){ #ggplot2
         plot.title <- paste(theTeam,"Batting partnership in match (vs.",opposition,")")
+
         ggplot(data=df,aes(x=batsman,y=runs,fill=nonStriker))+
             geom_bar(data=df,stat="identity") +
             xlab("Batmen") + ylab("Runs Scored") +
-            ggtitle(bquote(atop(.(plot.title),
-                                    atop(italic("Data source:http://cricsheet.org/"),"")))) +
+            labs(title=plot.title,subtitle="Data source:http://cricsheet.org/") +
             theme(axis.text.x = element_text(angle = 90, hjust = 1))
+
+    } else if(plot == 2){ #ggplotly
+        plot.title <- paste(theTeam,"Batting partnership in match (vs.",opposition,")")
+
+        g <- ggplot(data=df,aes(x=batsman,y=runs,fill=nonStriker))+
+            geom_bar(data=df,stat="identity") +
+            xlab("Batmen") + ylab("Runs Scored") +
+            labs(title=plot.title,subtitle="Data source:http://cricsheet.org/") +
+            theme(axis.text.x = element_text(angle = 90, hjust = 1))
+
+        ggplotly(g)
     }
     else{
         # Output dataframe
